package be.iminds.ilabt.jfed.experimenter_gui.events;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.io.File;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;

/**
 * User: twalcari
 * Date: 6/25/2015
 * Time: 17:43
 */
public class OpenESpecEvent {
    public enum ESpecSource { DIR, URL, ARCHIVE }
    @Nonnull private final ESpecSource eSpecSource;
    @Nullable private final File file;
    @Nullable private final URL url;

    public OpenESpecEvent(@Nonnull URL url) {
        this.file = null;
        this.eSpecSource = ESpecSource.URL;
        this.url = url;
    }

    public OpenESpecEvent(@Nonnull File file) {
        this.file = file;
        this.eSpecSource = file.isDirectory() ? ESpecSource.DIR : ESpecSource.ARCHIVE;
        this.url = null;
    }

    public OpenESpecEvent(@Nonnull String any) throws MalformedURLException {
        if (any.startsWith("http")) {
            this.file = null;
            this.eSpecSource = ESpecSource.URL;
            this.url = new URL(any);
        } else {
            this.file = new File(any);
            this.eSpecSource = file.isDirectory() ? ESpecSource.DIR : ESpecSource.ARCHIVE;
            this.url = null;
        }
    }

    @Nonnull
    public ESpecSource getESpecSource() {
        return eSpecSource;
    }

    @Nullable
    public File getFile() {
        return file;
    }

    @Nullable
    public URL getUrl() {
        return url;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof OpenESpecEvent)) return false;

        OpenESpecEvent that = (OpenESpecEvent) o;

        if (eSpecSource != that.eSpecSource) return false;
        if (file != null ? !file.equals(that.file) : that.file != null) return false;
        return url != null ? url.equals(that.url) : that.url == null;
    }

    @Override
    public int hashCode() {
        int result = eSpecSource.hashCode();
        result = 31 * result + (file != null ? file.hashCode() : 0);
        result = 31 * result + (url != null ? url.hashCode() : 0);
        return result;
    }

    @Override
    public String toString() {
        return "OpenESpecEvent{" +
                "eSpecSource=" + eSpecSource +
                ", file=" + file +
                ", url=" + url +
                '}';
    }
}
